@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,31 +13,17 @@
 #include <QApplication>
 #include <QIcon>
 
+#include <KIconTheme>
 #include <QCommandLineParser>
 #include <cstdio>
-#define HAVE_KICONTHEME __has_include(<KIconTheme>)
-#if HAVE_KICONTHEME
-#include <KIconTheme>
-#endif
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 
 int main(int argc, char *argv[])
 {
-#if HAVE_KICONTHEME
     KIconTheme::initTheme();
-#endif
     QApplication app(argc, argv);
-#if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
-#else // !HAVE_STYLE_MANAGER
-#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-    QApplication::setStyle(QStringLiteral("breeze"));
-#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-#endif // HAVE_STYLE_MANAGER
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("akonadiimportwizard"));
     // FIXME: "wizards" are "assistents" in new KDE slang
@@ -47,7 +33,7 @@ int main(int argc, char *argv[])
                          QStringLiteral(KDEPIM_VERSION),
                          i18n("PIM Import Tool"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2012-%1 ImportWizard authors", QStringLiteral("2023")));
+                         i18n("Copyright © 2012-%1 ImportWizard authors", QStringLiteral("2025")));
 
     aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact-import-wizard")));
